@@ -1,4 +1,9 @@
-class YextException(Exception):
+from requests import HTTPError
+
+class YextBaseException(Exception):
+    pass
+
+class YextException(HTTPError):
     pass
 
 class RequestException(YextException):
